@@ -428,7 +428,7 @@ QList<Declaration*> DUChainUtils::getInheriters(const Declaration* decl, uint& m
     return ret;
 
   if(decl->internalContext() && decl->internalContext()->type() == DUContext::Class)
-    FOREACH_ARRAY(IndexedDUContext importer, decl->internalContext()->indexedImporters()) {
+    FOREACH_ARRAY(const IndexedDUContext& importer, decl->internalContext()->indexedImporters()) {
       
       DUContext* imp = importer.data();
       
@@ -545,7 +545,7 @@ Declaration* DUChainUtils::getOverridden(const Declaration* decl) {
 DUContext* DUChainUtils::getFunctionContext(Declaration* decl) {
   DUContext* functionContext = decl->internalContext();
   if(functionContext && functionContext->type() != DUContext::Function) {
-    foreach(DUContext::Import import, functionContext->importedParentContexts()) {
+    foreach(const DUContext::Import& import, functionContext->importedParentContexts()) {
       DUContext* ctx = import.context(decl->topContext());
       if(ctx && ctx->type() == DUContext::Function)
         functionContext = ctx;
