@@ -44,6 +44,7 @@
 
 #include "classmodel.h"
 #include "classtree.h"
+#include "classwidget.h"
 #include <language/interfaces/editorcontext.h>
 #include <language/duchain/persistentsymboltable.h>
 #include <language/duchain/functiondeclaration.h>
@@ -236,7 +237,20 @@ void ClassBrowserPlugin::openDefinition()
   Q_ASSERT(a->data().canConvert<DUChainBasePointer>());
 
   DeclarationPointer declPtr = qvariant_cast<DUChainBasePointer>(a->data()).dynamicCast<Declaration>();
-  Declaration* bestDeclaration = getBestDeclaration<Declaration>(declPtr.data());
+  readLock.unlock();
+
+  // Delegate to real function
+  showDefinition(declPtr);
+}
+
+void ClassBrowserPlugin::showDefinition(DeclarationPointer declaration)
+{
+  DUChainReadLocker readLock(DUChain::lock());
+  
+  if ( !declaration )
+    return;
+
+  Declaration* bestDeclaration = getBestDeclaration<Declaration>(declaration.data());
 
   // If it's a function, find the function definition to go to the actual declaration.
   if ( bestDeclaration && bestDeclaration->isFunctionDeclaration() )
