@@ -51,8 +51,8 @@ struct CvsJob::Private
 };
 
 
-CvsJob::CvsJob(KDevelop::IPlugin* parent)
-    : VcsJob(parent), d(new Private)
+CvsJob::CvsJob(KDevelop::IPlugin* parent, KDevelop::OutputJob::OutputJobVerbosity verbosity)
+    : VcsJob(parent, verbosity), d(new Private)
 {
     d->vcsplugin = parent;
 }
@@ -179,6 +179,7 @@ void CvsJob::cancel()
 
 void CvsJob::slotProcessError( QProcess::ProcessError err)
 {
+    Q_UNUSED( err );
     // disconnect all connections to childproc's signals; they are no longer needed
     d->childproc->disconnect();
 
