@@ -256,7 +256,6 @@ KDevelop::ProjectFolderItem *GenericProjectManager::import( KDevelop::IProject *
 {
     KDevelop::ProjectFolderItem *projectRoot = new KDevelop::ProjectFolderItem( project, project->folder(), 0 );
     kDebug() << "imported new project" << project->name() << "at" << projectRoot->url();
-    projectRoot->setProjectRoot(true);
 
     ///TODO: check if this works for remote files when something gets changed through another KDE app
     if ( project->folder().isLocalFile() ) {
@@ -403,15 +402,13 @@ bool GenericProjectManager::rename(KDevelop::ProjectBaseItem* item, const KUrl&
     foreach ( KDevelop::ProjectFolderItem* parent, item->project()->foldersForUrl(destination.upUrl()) ) {
         if ( parent->type() == KDevelop::ProjectBaseItem::Folder ) {
             stopWatcher(parent);
-            KIO::CopyJob* job = KIO::move(source, destination);
-            bool success = KIO::NetAccess::synchronousRun( job, KDevelop::ICore::self()->uiController()->activeMainWindow() );
-            continueWatcher(parent);
+            bool success = KDevelop::renameUrl( item->project(), source, destination );
             if ( success ) {
-                item->setParent(parent);
-                return true;
-            } else {
-                return false;
+                item->parent()->takeRow( item->row() );
+                parent->appendRow( item );
             }
+            continueWatcher(parent);
+            return success;
         }
     }
     return false;
