@@ -37,12 +37,11 @@ namespace KDevelop
     class VcsRevision;
 }
 
-class StandardCopyJob : public KDevelop::VcsJob
+class StandardJob : public KDevelop::VcsJob
 {
     Q_OBJECT
     public:
-        StandardCopyJob(KDevelop::IPlugin* parent, const KUrl& source,
-                        const KUrl& dest, OutputJobVerbosity verbosity);
+        StandardJob(KDevelop::IPlugin* parent, KJob* job, OutputJobVerbosity verbosity);
         
         virtual QVariant fetchResults() { return QVariant(); }
         virtual void start();
@@ -53,7 +52,7 @@ class StandardCopyJob : public KDevelop::VcsJob
         void result(KJob*);
     
     private:
-        const KUrl m_source, m_dest;
+        KJob* m_job;
         KDevelop::IPlugin* m_plugin;
         JobStatus m_status;
 };
@@ -160,12 +159,15 @@ private slots:
     void parseGitDiffOutput(KDevelop::DVcsJob* job);
     void parseGitRepoLocationOutput(KDevelop::DVcsJob* job);
     void parseGitStatusOutput(KDevelop::DVcsJob* job);
+    void parseGitVersionOutput(KDevelop::DVcsJob* job);
     
     void ctxPushStash();
     void ctxPopStash();
     void ctxStashManager();
 
 private:
+    void addNotVersionedFiles(const QDir& dir, const KUrl::List& files);
+    
     //commit dialog "main" helper
     QStringList getLsFiles(const QDir &directory, const QStringList &args,
         KDevelop::OutputJob::OutputJobVerbosity verbosity);
@@ -177,6 +179,9 @@ private:
 
     QList<QStringList> branchesShas;
     KUrl::List m_urls;
+    
+    /** Tells if it's older than 1.7.0 or not */
+    bool m_oldVersion;
 };
 
 #endif
