@@ -31,11 +31,20 @@
 #include <ktexteditor/view.h>
 
 #include "snippet.h"
+#include "snippetrepository.h"
 
-SnippetCompletionItem::SnippetCompletionItem( Snippet* snippet )
+#include "snippetfeatures.h"
+
+#ifdef SNIPPETS_HAVE_TPLIFACE2
+#include <ktexteditor/templateinterface2.h>
+#endif
+
+SnippetCompletionItem::SnippetCompletionItem( Snippet* snippet, SnippetRepository* repo )
     : CompletionTreeItem(), m_name(snippet->text()), m_snippet(snippet->snippet()), m_prefix(snippet->prefix()),
-      m_arguments(snippet->arguments()), m_postfix(snippet->postfix())
+      m_arguments(snippet->arguments()), m_postfix(snippet->postfix()), m_repo(repo)
 {
+    Q_ASSERT(m_repo);
+    m_name.prepend( repo->completionNamespace() );
 }
 
 SnippetCompletionItem::~SnippetCompletionItem()
@@ -85,14 +94,23 @@ QVariant SnippetCompletionItem::data( const QModelIndex& index, int role, const
 void SnippetCompletionItem::execute( KTextEditor::Document* document, const KTextEditor::Range& word )
 {
     if ( document->activeView() ) {
+        QMap< QString, QString > values = QMap<QString, QString>();
+        if ( document->activeView()->selection() ) {
+            values["selection"] = document->text(document->activeView()->selectionRange());
+        }
+        document->removeText(word);
+        #ifdef SNIPPETS_HAVE_TPLIFACE2
+            if ( KTextEditor::TemplateInterface2* templateIface2 = qobject_cast<KTextEditor::TemplateInterface2*>(document->activeView()) ) {
+                if ( word != document->activeView()->selectionRange() ) {
+                    document->removeText(word);
+                }
+                templateIface2->insertTemplateText(word.start(), m_snippet, values, m_repo->registeredScript());
+                return;
+            }
+        #endif
         KTextEditor::TemplateInterface* templateIface
             = qobject_cast<KTextEditor::TemplateInterface*>(document->activeView());
         if ( templateIface ) {
-            QMap< QString, QString > values = QMap<QString, QString>();
-            if ( document->activeView()->selection() ) {
-                values["selection"] = document->text(document->activeView()->selectionRange());
-            }
-            document->removeText(word);
             templateIface->insertTemplateText(word.start(), m_snippet, values);
             return;
         }
