@@ -61,17 +61,10 @@ public:
     virtual KUrl::List includeDirectories(ProjectBaseItem*) const = 0;
 
     /**
-     * Provide a list of files that contain the preprocessor defines for the
-     * project
+     * Provide a list of preprocessor defines for the project item
      */
     virtual QHash<QString,QString> defines(ProjectBaseItem*) const = 0;
 
-    /**
-     * Provide a list of files that contains environment variables for the
-     * project
-     */
-    virtual QHash<QString,QString> environment(ProjectBaseItem*) const = 0;
-
     /**
      * Create a new target
      *
@@ -126,7 +119,6 @@ public:
 
 Q_DECLARE_OPERATORS_FOR_FLAGS( KDevelop::IBuildSystemManager::BuildFeatures )
 
-KDEV_DECLARE_EXTENSION_INTERFACE_NS( KDevelop, IBuildSystemManager, "org.kdevelop.IBuildSystemManager" )
 Q_DECLARE_INTERFACE( KDevelop::IBuildSystemManager, "org.kdevelop.IBuildSystemManager" )
 
 #endif
